==> libgoose-0.0.1.tar.gz: libgoose-0.0.1/examples/boot_bench.cc <==
// This is -*- C++ -*-
// $Id: boot_bench.cc,v 1.1 1998/08/19 20:53:56 trow Exp $

/* boot_bench.cc
 *
 * Copyright (C) 1998 EMC Capital Management, Inc.
 *
 * Developed by Jon Trowbridge <trow@emccta.com>.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA.
 */


#include <iostream.h>
#include <time.h>
#include "DataSet.h"
#include "bootstrap.h"
#include "Random.h"

main()
{
  const int SAMPLES = 5000;
  const int TRIALS = 100000;
  const double COUNT = TRIALS*(double)SAMPLES;
  Random rnd;
  DataSet ds;
  for(int i=0; i<SAMPLES; ++i)
    ds.add(rnd.random_normal());

  time_t t1, t2;
  double t;

  time(&t1);
  DataSet* b = bootstrap_mean(TRIALS, ds);
  time(&t2);
  t = t2-t1;
  delete b;
  cout << "----- Bootstrap Mean -----" << endl;
  cout << "         Time: " << t << endl;
  cout << "Resamples/sec: " << TRIALS/t << endl;
  cout << " Mil Elem/sec: " << COUNT/t/1e+6 << endl << endl;

  time(&t1);
  b = bootstrap_median(TRIALS, ds);
  time(&t2);
  t = t2-t1;
  delete b;
  cout << "----- Bootstrap Median -----" << endl;
  cout << "         Time: " << t << endl;
  cout << "Resamples/sec: " << TRIALS/t << endl;
  cout << " Mil Elem/sec: " << COUNT/t/1e+6 << endl << endl;

    
}




// $Id: boot_bench.cc,v 1.1 1998/08/19 20:53:56 trow Exp $

==> libgoose-0.0.2.tar.gz: libgoose-0.0.2/examples/boot_bench.cc <==
// This is -*- C++ -*-
// $Id: boot_bench.cc,v 1.3 1998/09/14 04:47:42 trow Exp $

/* boot_bench.cc
 *
 * Copyright (C) 1998 EMC Capital Management, Inc.
 *
 * Developed by Jon Trowbridge <trow@emccta.com>.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA.
 */


#include <iostream.h>
#include <time.h>
#include "DataSet.h"
#include "bootstrap.h"
#include "Random.h"

main()
{
  const int SAMPLES = 5000;
  const int TRIALS = 100000;
  const double COUNT = TRIALS*(double)SAMPLES;
  Random rnd;
  DataSet ds;
  for(int i=0; i<SAMPLES; ++i)
    ds.add(rnd.random_normal());

  time_t t1, t2;
  double t;

  time(&t1);
  DataSet b = bootstrap_mean(TRIALS, ds);
  time(&t2);
  t = t2-t1;
  cout << "----- Bootstrap Mean -----" << endl;
  cout << "         Time: " << t << endl;
  cout << "Resamples/sec: " << TRIALS/t << endl;
  cout << " Mil Elem/sec: " << COUNT/t/1e+6 << endl << endl;

  time(&t1);
  b = bootstrap_median(TRIALS, ds);
  time(&t2);
  t = t2-t1;
  cout << "----- Bootstrap Median -----" << endl;
  cout << "         Time: " << t << endl;
  cout << "Resamples/sec: " << TRIALS/t << endl;
  cout << " Mil Elem/sec: " << COUNT/t/1e+6 << endl << endl;

    
}




// $Id: boot_bench.cc,v 1.3 1998/09/14 04:47:42 trow Exp $
